###################################################################
# create_candidates.py
# or "05 Create Scarp Polygon Candidates" tool in the SICCM toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/11/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
###################################################################

# Import arcpy module
import arcpy, os
from arcpy.sa import *
arcpy.env.overwriteOutput=True
arcpy.CheckOutExtension("spatial")

# Ask user for input mixture raster
mix_raster = arcpy.GetParameterAsText(0)
iCS = mix_raster.find("CS")
mix_extn = mix_raster[iCS:]
arcpy.AddMessage(mix_extn)

# Find location of input
descInput = arcpy.Describe(mix_raster)
arcpy.env.workspace = os.path.dirname(descInput.catalogPath)

# Display output location
loc = arcpy.env.workspace
commentval = "Outputs will be saved to "+loc
arcpy.AddMessage(commentval)

# # Determine cellsize of mixture raster
# description = arcpy.Describe(mix_raster)
# cellsize = description.children[0].meanCellHeight
# res = str(int(round(cellsize)))

# Find mixture threshold in layer's symbology
mxd = arcpy.mapping.MapDocument("CURRENT")
lyrMix = arcpy.mapping.ListLayers(mxd,mix_raster)[0]
UserThresh = lyrMix.symbology.classBreakValues

# Assign temporary variables
SliceMix = "SliceMixTemp"
ExtractTrough = "ExtractTrough"
ExtractPoly = "ExtractPoly"

# Set reclassification parameters and reclassify
Reclassification = RemapRange([[UserThresh[0], UserThresh[2], 0], [UserThresh[2], UserThresh[3], 1]])
OutReclass = Reclassify(mix_raster, "VALUE", Reclassification, "DATA")
OutReclass.save(SliceMix)
extn = "MT"+str(int(round(UserThresh[2])))

Candidates = "Cand_"+mix_extn+"_"+extn


# Extract all raster cells with a value of 1
OutExtract = ExtractByAttributes(SliceMix, "\"VALUE\" =1")
OutExtract.save(ExtractTrough)
    
# Convert extracted raster cells into candidate polygons
arcpy.RasterToPolygon_conversion(ExtractTrough, ExtractPoly, "SIMPLIFY", "VALUE")

arcpy.MakeFeatureLayer_management(ExtractPoly, "polys")
arcpy.SelectLayerByAttribute_management ("polys", "NEW_SELECTION", '"GRIDCODE" =1')
arcpy.CopyFeatures_management("polys", Candidates)


# Delete temporary variables
arcpy.Delete_management(ExtractPoly)
arcpy.Delete_management(ExtractTrough)
arcpy.Delete_management(SliceMix)

# Add perimeter and length attributes to the candidate polygons
arcpy.AddGeometryAttributes_management(Candidates, "AREA;PERIMETER_LENGTH", "", "", "")

# Create candidates layer
arcpy.MakeFeatureLayer_management(Candidates, "candidates")

# Check if field LS exists in candidates. If not, create it
check = 0
lst = arcpy.ListFields("candidates")
for f in lst:
	if f.name == "LS":
		check = 1
	else:
		continue
if check == 0:
	arcpy.AddField_management("candidates", "LS", "SHORT")
arcpy.Delete_management("candidates")
## Display candidates on map

# Set the map document and data frame

df = arcpy.mapping.ListDataFrames(mxd,"Layers")[0]
arcpy.Delete_management("polys")


# Create layer file and add to map
lyrDir = os.path.dirname(__file__)

fileCand = lyrDir+"\\candidates.lyr"
lyrCand = arcpy.mapping.Layer(Candidates)


arcpy.ApplySymbologyFromLayer_management(lyrCand, fileCand)
arcpy.mapping.AddLayer(df,lyrCand)

arcpy.CheckInExtension("spatial")

