##########################################################################
# create_project.py
# or "01 Create Inventory Mapping Project" tool in the SICCM toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/11/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
##########################################################################

# Import proper modules
import arcpy, os
arcpy.env.overwriteOutput=True

# As user for inputs
proj_loc = arcpy.GetParameterAsText(0)
proj_name = arcpy.GetParameterAsText(1)
InputDEM = arcpy.GetParameterAsText(2)

directory = proj_loc+"\\"+proj_name

# Create new folder
if not os.path.exists(directory):
	os.makedirs(directory)

# Create file geodatabase
gdbdir = directory+"\\"+proj_name+".gdb"

if not os.path.exists(gdbdir):
	arcpy.CreateFileGDB_management(directory, proj_name, "10.0")
	
# Temporarily set the file geodatabase as the workspace
arcpy.env.workspace = gdbdir
	
# Copy DEM to file geodatabase
OrigDEM = "Raw_DEM"
arcpy.CopyRaster_management(InputDEM,OrigDEM)

# Add DEM to map
mxd = arcpy.mapping.MapDocument("CURRENT")
df = arcpy.mapping.ListDataFrames(mxd,"Layers")[0]
lyrDEM = arcpy.mapping.Layer(OrigDEM)
arcpy.mapping.AddLayer(df,lyrDEM)