##########################################################################
# eliminate_non_scarps.py
# or "08 Eliminate of Non Scarp Topography" tool in the CCM Flow toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/17/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
##########################################################################

# Import arcpy module
import arcpy, os
from arcpy.sa import *
arcpy.env.overwriteOutput=True
arcpy.CheckOutExtension("spatial")
# Ask user for candidates shapefile
Candidates = arcpy.GetParameterAsText(0)

# Create candidates layer
arcpy.MakeFeatureLayer_management(Candidates, "candidates2")

# Check if field LS exists in candidates. If not, create it
check = 0
lst = arcpy.ListFields("candidates2")
for f in lst:
    if f.name == "LS":
        check = 1
    else:
        continue
if check == 0:
    arcpy.AddField_management("candidates2", "LS", "SHORT")

# Assign a value of 1 to all candidates
arcpy.CalculateField_management("candidates2", "LS", 1)

# Ask user for digitized non scarp topography shapefiles
NonScarps = arcpy.GetParameterAsText(1)
non_list = NonScarps.split(";")

# Specify search distance
search_distance = "0 Feet"


# Process each non scarp layer
for NonScarps in non_list:
	arcpy.AddMessage("Processing: {}".format(NonScarps))

    # Create temporary layer for current non scarp
	arcpy.MakeFeatureLayer_management(NonScarps,"NonScarp")

    # Select candidates that are within the search distance of a non scarp
	arcpy.SelectLayerByLocation_management("candidates2", "WITHIN_A_DISTANCE", "NonScarp", search_distance, "NEW_SELECTION")

    # Change LS value to 0 for selected candidates
	arcpy.CalculateField_management("candidates2","LS", 0)

    # Clear selected candidates
	arcpy.SelectLayerByAttribute_management("candidates2", "CLEAR_SELECTION")
	
    # Delete temporary non scarp layer
	arcpy.Delete_management("NonScarp")
	
	

# # Set the map document and data frame
# mxd = arcpy.mapping.MapDocument("CURRENT")
# df = arcpy.mapping.ListDataFrames(mxd,"Layers")[0]
# # Create layer file and add to map
# lyrDir = os.path.dirname(__file__)

# fileCand = lyrDir+"\\candidates.lyr"
# lyrCand = arcpy.mapping.Layer(Candidates)
# dir, fname = os.path.split(Candidates)

# for lyr in arcpy.mapping.ListLayers(mxd, "", df):
	# if lyr.name == Candidates:
		# arcpy.mapping.RemoveLayer(df, lyrCand)
	# elif lyr.name == "candidates2":
		# arcpy.mapping.RemoveLayer(df, lyrCand)
# arcpy.ApplySymbologyFromLayer_management(lyrCand, fileCand)
# arcpy.mapping.AddLayer(df,lyrCand)

arcpy.Delete_management("candidates2")
arcpy.CheckInExtension("spatial")