##################################################################
# prepare_visualization_layers.py
# or "02 Prepare Visualization Layers" tool in the SICCM toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/11/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
##################################################################

# Import arcpy module
import arcpy, os
from arcpy.sa import *
arcpy.env.overwriteOutput=True

# Check out any necessary licenses
arcpy.CheckOutExtension("spatial")

# Ask user for input DEM
InputDEM = arcpy.GetParameterAsText(0)

# Find location of input
descInput = arcpy.Describe(InputDEM)
arcpy.env.workspace = os.path.dirname(descInput.catalogPath)

# Display output location
loc = arcpy.env.workspace
commentval = "Outputs will be saved to "+loc
arcpy.AddMessage(commentval)

# Ask user for output file locations
OrigDEM = InputDEM
OutputSlopeFR = "Slope"
OutputHills = "Hillshade"

# Compute new rasters
outSlopeFR = Slope(InputDEM, "DEGREE", "")
outSlopeFR.save(OutputSlopeFR)
outHS = Hillshade(InputDEM, "", "", "", 1)
outHS.save(OutputHills)

arcpy.CheckInExtension("spatial")

## Display mixture raster on map

# Set the map document and data frame
mxd = arcpy.mapping.MapDocument("CURRENT")
df = arcpy.mapping.ListDataFrames(mxd,"Layers")[0]

# Find location of layer file
lyrDir = os.path.dirname(__file__)

fileSlp = lyrDir+"\\slope.lyr"
fileDEM = lyrDir+"\\dem.lyr"
fileHS = lyrDir+"\\hillshade.lyr"



lyrDEM = arcpy.mapping.Layer(OrigDEM)

		
arcpy.mapping.RemoveLayer(df, arcpy.mapping.ListLayers(mxd, 'Raw_DEM')[0])
		
lyrHS = arcpy.mapping.Layer(OutputHills)
arcpy.ApplySymbologyFromLayer_management(lyrHS, fileHS)
arcpy.mapping.AddLayer(df,lyrHS)

# Create layer file and add to map
lyrSlp = arcpy.mapping.Layer(OutputSlopeFR)
arcpy.ApplySymbologyFromLayer_management(lyrSlp, fileSlp)
arcpy.mapping.AddLayer(df,lyrSlp)

arcpy.ApplySymbologyFromLayer_management(lyrDEM, fileDEM)
arcpy.mapping.AddLayer(df,lyrDEM)

arcpy.CheckInExtension("Spatial")

arcpy.RefreshCatalog(arcpy.env.workspace)